[GitHub] libcloud pull request: Modified/cleaned up Google tests. Tests wer...

2015-12-01 Thread crunk1
GitHub user crunk1 opened a pull request:

https://github.com/apache/libcloud/pull/648

Modified/cleaned up Google tests. Tests were not hermetic, but now pr…

…oper mocking has been put in place to make them hermetic.

@erjohnso 
@jimbobhickville

You can merge this pull request into a Git repository by running:

$ git pull https://github.com/crunk1/libcloud trunk

Alternatively you can review and apply these changes as the patch at:

https://github.com/apache/libcloud/pull/648.patch

To close this pull request, make a commit to your master/trunk branch
with (at least) the following in the commit message:

This closes #648


commit aefd13f1612530fed6c3bfa5b1764f32b09599f3
Author: Scott Crunkleton 
Date:   2015-12-02T01:21:50Z

Modified/cleaned up Google tests. Tests were not hermetic, but now proper 
mocking has been put in place to make them hermetic.




---
If your project is set up for it, you can reply to this email and have your
reply appear on GitHub as well. If your project does not have this feature
enabled and wishes so, or if the feature is enabled but not working, please
contact infrastructure at infrastruct...@apache.org or file a JIRA ticket
with INFRA.
---


libcloud git commit: Add support for service_name in _parse_service_catalog_auth_v3

2015-12-01 Thread anthonyshaw
Repository: libcloud
Updated Branches:
  refs/heads/trunk b7d851f14 -> 990ecf7c6


Add support for service_name in _parse_service_catalog_auth_v3

Signed-off-by: Anthony Shaw 
Closes #647


Project: http://git-wip-us.apache.org/repos/asf/libcloud/repo
Commit: http://git-wip-us.apache.org/repos/asf/libcloud/commit/990ecf7c
Tree: http://git-wip-us.apache.org/repos/asf/libcloud/tree/990ecf7c
Diff: http://git-wip-us.apache.org/repos/asf/libcloud/diff/990ecf7c

Branch: refs/heads/trunk
Commit: 990ecf7c609f9fe53ab7508b0d345c726a1e4a49
Parents: b7d851f
Author: Steve Gregory 
Authored: Tue Dec 1 12:15:40 2015 -0700
Committer: Anthony Shaw 
Committed: Wed Dec 2 12:45:44 2015 +1100

--
 libcloud/common/openstack_identity.py | 2 ++
 1 file changed, 2 insertions(+)
--


http://git-wip-us.apache.org/repos/asf/libcloud/blob/990ecf7c/libcloud/common/openstack_identity.py
--
diff --git a/libcloud/common/openstack_identity.py 
b/libcloud/common/openstack_identity.py
index 3eb0d14..ac90424 100644
--- a/libcloud/common/openstack_identity.py
+++ b/libcloud/common/openstack_identity.py
@@ -419,6 +419,7 @@ class OpenStackServiceCatalog(object):
 
 for item in service_catalog:
 service_type = item['type']
+service_name = item.get('name', None)
 
 entry_endpoints = []
 for endpoint in item['endpoints']:
@@ -438,6 +439,7 @@ class OpenStackServiceCatalog(object):
 entry_endpoints.append(entry_endpoint)
 
 entry = OpenStackServiceCatalogEntry(service_type=service_type,
+ service_name=service_name,
  endpoints=entry_endpoints)
 entries.append(entry)
 



[jira] [Commented] (LIBCLOUD-775) Add support for updating node specification in Dimension Data driver

2015-12-01 Thread ASF subversion and git services (JIRA)

[ 
https://issues.apache.org/jira/browse/LIBCLOUD-775?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel=15035195#comment-15035195
 ] 

ASF subversion and git services commented on LIBCLOUD-775:
--

Commit e8e758d9c690916f2c33e8d0afdd2a7cc9a07552 in libcloud's branch 
refs/heads/trunk from [~anthonypjshaw]
[ https://git-wip-us.apache.org/repos/asf?p=libcloud.git;h=e8e758d ]

LIBCLOUD-775 Update node, update VMware tools, add storage, change storage size 
or speed, remove storage. With tests

Signed-off-by: Anthony Shaw 


> Add support for updating node specification in Dimension Data driver
> 
>
> Key: LIBCLOUD-775
> URL: https://issues.apache.org/jira/browse/LIBCLOUD-775
> Project: Libcloud
>  Issue Type: Improvement
>Reporter: Anthony Shaw
>




--
This message was sent by Atlassian JIRA
(v6.3.4#6332)


[3/3] libcloud git commit: Update CHANGES.rst with recent closed PRs

2015-12-01 Thread anthonyshaw
Update CHANGES.rst with recent closed PRs


Project: http://git-wip-us.apache.org/repos/asf/libcloud/repo
Commit: http://git-wip-us.apache.org/repos/asf/libcloud/commit/5b26ac4d
Tree: http://git-wip-us.apache.org/repos/asf/libcloud/tree/5b26ac4d
Diff: http://git-wip-us.apache.org/repos/asf/libcloud/diff/5b26ac4d

Branch: refs/heads/trunk
Commit: 5b26ac4dd6e56d29a7cb0028dc6acb7d5fd4bb45
Parents: 36ed630
Author: Anthony Shaw 
Authored: Wed Dec 2 14:21:15 2015 +1100
Committer: Anthony Shaw 
Committed: Wed Dec 2 14:21:15 2015 +1100

--
 CHANGES.rst | 26 +++---
 1 file changed, 19 insertions(+), 7 deletions(-)
--


http://git-wip-us.apache.org/repos/asf/libcloud/blob/5b26ac4d/CHANGES.rst
--
diff --git a/CHANGES.rst b/CHANGES.rst
index b57cc5f..acb97c1 100644
--- a/CHANGES.rst
+++ b/CHANGES.rst
@@ -26,6 +26,18 @@ General
 Compute
 ~~~
 
+- Add update node, update VMware tools, add storage, change storage size or 
speed, remove storage.
+  (LIBCLOUD-775, GITHUB-644)
+  [Anthony Shaw]
+
+- Include 'service_name' support in _parse_service_catalog_auth_v3 for 
Openstack Drivers
+  (GITHUB-647)
+  [Steve Gregory]
+
+- Outscale inc & sas driver update
+  (GITHUB-645)
+  [@LordShion]
+
 - Add new `eu-west-2` & `us-east-2` regions to the OUTSCALE_INC & OUTSCALE_SAS 
drivers.
   [Filipe Silva /lordshion]
 
@@ -58,32 +70,32 @@ Compute
 
 - Allow user to wait for a resource to reach a desired state in the
   Dimension Data driver by using new ``ex_wait_for_state`` method.
-  [LIBCLOUD-707, GITHUB-631]
+  (LIBCLOUD-707, GITHUB-631)
   [Anthony Shaw]
   
 - Added M4 pricing and instance information to EC2 driver
-  [GITHUB-634]
+  (GITHUB-634)
   [Benjamin Zaitlen]
 
 - Added C4 instance information to EC2 driver
-  [GITHUB-638]
+  (GITHUB-638)
   [amitofs]
   
 - Allow location of the datacenter to be supplied in ProfitBricks driver
-  [LIBCLOUD-771, GITHUB-635]
+  (LIBCLOUD-771, GITHUB-635)
   [Joel Reymont]
 
 - Reduce redundant API calls in CloudStack driver
-  [LIBCLOUD-590, GITHUB-641]
+  (LIBCLOUD-590, GITHUB-641)
   [Atsushi Sasaki]
 
 - Add an additional argument to 
libcloud.compute.drivers.GCENodeDriver.create_node
   to allow for creation of preemptible GCE instances
-  [GITHUB-643]
+  (GITHUB-643)
   [@blawney]
 
 - GoogleStorageDriver can now use either our S3 authentication or other Google 
Cloud Platform OAuth2 authentication methods.
-  [GITHUB-633]
+  (GITHUB-633)
   [Scott Crunkleton]
 
 Storage



[2/3] libcloud git commit: Updated the comments

2015-12-01 Thread anthonyshaw
Updated the comments

Signed-off-by: Anthony Shaw 
Closes #644


Project: http://git-wip-us.apache.org/repos/asf/libcloud/repo
Commit: http://git-wip-us.apache.org/repos/asf/libcloud/commit/36ed6304
Tree: http://git-wip-us.apache.org/repos/asf/libcloud/tree/36ed6304
Diff: http://git-wip-us.apache.org/repos/asf/libcloud/diff/36ed6304

Branch: refs/heads/trunk
Commit: 36ed6304551424ebca91b24010bd9ea71743e941
Parents: e8e758d
Author: Anthony Shaw 
Authored: Wed Dec 2 14:04:37 2015 +1100
Committer: Anthony Shaw 
Committed: Wed Dec 2 14:11:34 2015 +1100

--
 libcloud/compute/drivers/dimensiondata.py | 12 ++--
 1 file changed, 6 insertions(+), 6 deletions(-)
--


http://git-wip-us.apache.org/repos/asf/libcloud/blob/36ed6304/libcloud/compute/drivers/dimensiondata.py
--
diff --git a/libcloud/compute/drivers/dimensiondata.py 
b/libcloud/compute/drivers/dimensiondata.py
index 1a0ae09..5757418 100644
--- a/libcloud/compute/drivers/dimensiondata.py
+++ b/libcloud/compute/drivers/dimensiondata.py
@@ -1282,12 +1282,12 @@ class DimensionDataNodeDriver(NodeDriver):
 
 def ex_change_storage_speed(self, node, disk_id, speed):
 """
-Remove storage from a node
+Change the speed (disk tier) of a disk
 
-:param  node: The server to add storage to
+:param  node: The server to change the disk speed of
 :type   node: :class:`Node`
 
 :param  disk_id: The ID of the disk to remove
 :type   disk_id: ``str``
 
 :param  speed: The disk speed type e.g. STANDARD
@@ -1307,12 +1307,12 @@ class DimensionDataNodeDriver(NodeDriver):
 
 def ex_change_storage_size(self, node, disk_id, size):
 """
-Remove storage from a node
+Change the size of a disk
 
 :param  node: The server to add storage to
 :type   node: :class:`Node`
 
-:param  disk_id: The ID of the disk to remove
+:param  disk_id: The ID of the disk to resize
 :type   disk_id: ``str``
 
 :param  size: The disk size in GB



[jira] [Commented] (LIBCLOUD-775) Add support for updating node specification in Dimension Data driver

2015-12-01 Thread ASF GitHub Bot (JIRA)

[ 
https://issues.apache.org/jira/browse/LIBCLOUD-775?page=com.atlassian.jira.plugin.system.issuetabpanels:comment-tabpanel=15035196#comment-15035196
 ] 

ASF GitHub Bot commented on LIBCLOUD-775:
-
@@ -1282,12 +1282,12 @@ class DimensionDataNodeDriver(NodeDriver):
 :type   node: :class:`Node`
 
-:param  disk_id: The ID of the disk to remove
+:param  disk_id: The ID of the disk to change
 :type   disk_id: ``str``
 
@@ -1307,12 +1307,12 @@ class DimensionDataNodeDriver(NodeDriver):
 
-:param  node: The server to add storage to
+:param  node: The server to change the disk of
 :type   node: :class:`Node`
 

Github user asfgit closed the pull request at:

https://github.com/apache/libcloud/pull/644


> Add support for updating node specification in Dimension Data driver
> 
>
> Key: LIBCLOUD-775
> URL: https://issues.apache.org/jira/browse/LIBCLOUD-775
> Project: Libcloud
>  Issue Type: Improvement
>Reporter: Anthony Shaw
>




--
This message was sent by Atlassian JIRA
(v6.3.4#6332)


[GitHub] libcloud pull request: Include 'service_name' support in _parse_se...

2015-12-01 Thread steve-gregory
GitHub user steve-gregory opened a pull request:

https://github.com/apache/libcloud/pull/647

Include 'service_name' support in _parse_service_catalog_auth_v3 for 
Openstack Drivers

The 'service_name' attribute was being left out when parsing the v3 
ServiceCatalog returned by OpenStack. As a result, this error would occur: 
`LibcloudError: `

The solution is to parse and add the service_name to the 
`OpenStackServiceCatalogEntry` similar to how it was done in 
`_parse_service_catalog_auth_v2`.

You can merge this pull request into a Git repository by running:

$ git pull https://github.com/iPlantCollaborativeOpenSource/libcloud trunk

Alternatively you can review and apply these changes as the patch at:

https://github.com/apache/libcloud/pull/647.patch

To close this pull request, make a commit to your master/trunk branch
with (at least) the following in the commit message:

This closes #647


commit 34e2f85b7a83a1cf2f7339b4fa4e7980af02a811
Author: Steve Gregory 
Date:   2015-12-01T19:15:40Z

Add support for service_name in _parse_service_catalog_auth_v3




---
If your project is set up for it, you can reply to this email and have your
reply appear on GitHub as well. If your project does not have this feature
enabled and wishes so, or if the feature is enabled but not working, please
contact infrastructure at infrastruct...@apache.org or file a JIRA ticket
with INFRA.
---


[GitHub] libcloud pull request: EC2 updates

2015-12-01 Thread pmhahn
GitHub user pmhahn opened a pull request:

https://github.com/apache/libcloud/pull/646

EC2 updates

The EC2 Instance Type information contains some errors (especially the disk 
size for the m3 instances), conversion errors between GiB an M[i]B, disk count, 
..
Also g2.8xlarge and t2.large are missing.

You can merge this pull request into a Git repository by running:

$ git pull https://github.com/pmhahn/libcloud trunk

Alternatively you can review and apply these changes as the patch at:

https://github.com/apache/libcloud/pull/646.patch

To close this pull request, make a commit to your master/trunk branch
with (at least) the following in the commit message:

This closes #646


commit 65e493f41a085e6164173fc7c73853e99f46c82e
Author: Philipp Hahn 
Date:   2015-12-01T07:51:17Z

EC2: Specify RAM size in GiB

The values on  are
given in [GiB].

Let Python convert them to [MiB], as the current values are a mix of
[MB] and [MiB].

commit cb21959e307fa81a9d3bf5fd4483eb508250d883
Author: Philipp Hahn 
Date:   2015-12-01T07:56:15Z

EC2: Fix disk size

The values on  are
given in [GB].

Let Python calculate the size of multiple disks.

Remove wrong factor 1000 from m3 instances.

commit 0fd6d88a292b10e98590e143f20a3cadc6588b41
Author: Philipp Hahn 
Date:   2015-12-01T07:59:52Z

EC2: Add missing vCPU information

Add vCPU information from


commit a646c1c90d2086cb4b3ed1ca0b6c1f4d7fc83de8
Author: Philipp Hahn 
Date:   2015-12-01T08:01:10Z

EC2: Add g2.8xlarge and t2.large

From 

commit ad547b33b2942e641213883d28b08d91d4ad11b5
Author: Philipp Hahn 
Date:   2015-12-01T08:03:40Z

EC2: Rename i2 and d2 instance types

i2 are I/O optimized, while d2 are dense optimized

commit 40d11645f4d854cc6ab298608a99fc0f1a85ce67
Author: Philipp Hahn 
Date:   2015-12-01T08:05:02Z

EC2: Move comment before t2 instances

t2.micro is also a "Burstable Performance General Purpose" instance
type.

commit a1aeb0c7bba6c7db879996d06650693bc2c30a1b
Author: Philipp Hahn 
Date:   2015-12-01T08:05:37Z

EC2: Add clarifications

Add source URLs.
Add unit type for RAM and disk size.




---
If your project is set up for it, you can reply to this email and have your
reply appear on GitHub as well. If your project does not have this feature
enabled and wishes so, or if the feature is enabled but not working, please
contact infrastructure at infrastruct...@apache.org or file a JIRA ticket
with INFRA.
---